@@ -1,7 +1,7 @@
 ##----------------------------------------------------------------------------
 ## Stripe API - ~/lib/Net/API/Stripe/Charge/Refunds.pm
 ## Version 0.1
-## Copyright(c) 2019 DEGUEST Pte. Ltd.
+## Copyright(c) 2019-2020 DEGUEST Pte. Ltd.
 ## Author: Jacques Deguest <jack@deguest.jp>
 ## Created 2019/11/02
 ## Modified 2019/11/02
@@ -36,3 +36,32 @@ BEGIN
 1;
 
 __END__
+
+=encoding utf8
+
+=head1 NAME
+
+Net::API::Stripe::Charge::Refunds - A Stripe Refunds List Object
+
+=head1 DESCRIPTION
+
+This module inherits completely from L<Net::API::Stripe::List> and may be removed in the future.
+
+=head1 AUTHOR
+
+Jacques Deguest E<lt>F<jack@deguest.jp>E<gt>
+
+=head1 SEE ALSO
+
+Stripe API documentation:
+
+L<https://stripe.com/docs/api/invoices/line_item>
+
+=head1 COPYRIGHT & LICENSE
+
+Copyright (c) 2019-2020 DEGUEST Pte. Ltd.
+
+You can use, copy, modify and redistribute this package and associated
+files under the same terms as Perl itself.
+
+=cut
